@@ -7,8 +7,9 @@
 
 
 from .component import forms
-
+from .cache import cache
 
 __all__ = [
     'forms',
+    'cache'
 ]
